# Import necessary libraries
import streamlit as st
import pandas as pd
import ml_algorithms as mla


# Create a Streamlit title
st.title("KMeans and Decision Tree Application")

# Create a file uploader widget for uploading a tab-separated TXT file
uploaded_file = st.file_uploader("Upload a tab-separated TXT file (no header)", type="txt")

# Check if a file has been uploaded
if uploaded_file is not None:
    # Read the uploaded file as a DataFrame using pandas, assuming no header
    data = pd.read_csv(uploaded_file, sep='\t', header=None)
    
    # Display a preview of the data
    st.write("Data aaaaa:")
    st.write(data.head())


    # Create a number input widget for specifying the number of clusters for k-means clustering
    n_clusters = st.number_input("Enter the number of clusters for KMeans:", min_value=2, value=2)

    # Create a number input widget for specifying the max depth for the decision tree
    max_depth = st.number_input("Enter the max depth for the Decision Tree:", min_value=1, value=3)

    # Create a button to start the analysis
    if st.button("Start Analysis"):
        # Separate the features (K-1 columns) and the target (last column) from the data
        features = data.iloc[:, :-1]
        target = data.iloc[:, -1]

        # Run k-means clustering and decision tree classification on the data
        kmeans_labels, kmeans_score = mla.run_kmeans(features, n_clusters)
        dt_accuracy = mla.run_decision_tree(features, target, max_depth)

        # Display the evaluation results in a table
        st.write("Evaluation Results:")
        st.write(pd.DataFrame({"Method": ["KMeans (Silhouette Score)", "Decision Tree (Accuracy)"],
                               "Score": [kmeans_score, dt_accuracy]}))
