from sklearn.tree import DecisionTreeClassifier
from sklearn.cluster import KMeans
from sklearn.metrics import silhouette_score
from sklearn.model_selection import train_test_split
from sklearn.metrics import accuracy_score


# Function to run k-means clustering and calculate the silhouette score
# This is a test
def run_kmeans(data, k):
    kmeans = KMeans(n_clusters=k)  # Create a KMeans instance with the specified number of clusters
    kmeans.fit(data)               # Fit the KMeans model to the data
    labels = kmeans.labels_        # Get the cluster labels for each data point
    score = silhouette_score(data, labels)  # Calculate the silhouette score for the clustering
    return labels, score

# Function to run decision tree classification and calculate the accuracy
def run_decision_tree(X, y, max_depth):
    # Split the data into training and testing sets (70% training, 30% testing)
    X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.3, random_state=42)
    
    dt = DecisionTreeClassifier(max_depth=max_depth)  # Create a DecisionTreeClassifier instance with the specified max_depth
    dt.fit(X_train, y_train)       # Fit the classifier to the training data
    y_pred = dt.predict(X_test)    # Predict labels for the test data
    accuracy = accuracy_score(y_test, y_pred)  # Calculate the accuracy of the classifier
    return accuracy